<!DOCTYPE TS><TS>
<context>
    <name>QApplication</name>
    <message>
        <source>Executable &apos;%1&apos; requires Qt %2, found Qt %3.</source>
        <translation>Program &apos;%1&apos; wymaga Qt %2, znaleziono Qt %3.</translation>
    </message>
    <message>
        <source>Incompatible Qt Library Error</source>
        <translation>Niekompatybilna biblioteka Qt</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>Cze&amp;rwony:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Zielony:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>&amp;Niebieski:</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>&amp;Kolory podstawowe</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>K&amp;olory użytkownika</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation>&amp;Definiuj własne kolory &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Porzuć</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>Dod&amp;aj do własnych kolorów</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation>Wybierz kolor</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <source>What&apos;s This?</source>
        <translation>Co to jest?</translation>
    </message>
</context>
<context>
    <name>QErrorMessage</name>
    <message>
        <source>Debug Message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning:</source>
        <translation>Ostrzeżenie:</translation>
    </message>
    <message>
        <source>Fatal Error:</source>
        <translation>Fatalny Błąd:</translation>
    </message>
    <message>
        <source>&amp;Show this message again</source>
        <translation>&amp;Pokaż jeszcze raz ten komunikat</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Copy or Move a File</source>
        <translation>Kopiuj lub przenieś plik</translation>
    </message>
    <message>
        <source>Read: %1</source>
        <translation>Odczyt: %1</translation>
    </message>
    <message>
        <source>Write: %1</source>
        <translation>Zapis: %1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Porzuć</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Attributes</source>
        <translation>Atrybuty</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Look &amp;in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>&amp;Nazwa pliku:</translation>
    </message>
    <message>
        <source>File &amp;type:</source>
        <translation>&amp;Typ pliku:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Powrót</translation>
    </message>
    <message>
        <source>One directory up</source>
        <translation>Poziom wyżej</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Stwórz nowy katalog</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Lista</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Preview File Info</source>
        <translation></translation>
    </message>
    <message>
        <source>Preview File Contents</source>
        <translation>Podgląd zawartości pliku</translation>
    </message>
    <message>
        <source>Read-write</source>
        <translation>Odczyt-zapis</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Tylko do odczytu</translation>
    </message>
    <message>
        <source>Write-only</source>
        <translation>Tylko do zapisu</translation>
    </message>
    <message>
        <source>Inaccessible</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Symlink to File</source>
        <translation>Dowiązanie symboliczne do pliku</translation>
    </message>
    <message>
        <source>Symlink to Directory</source>
        <translation>Dowiązanie symboliczne do katalogu</translation>
    </message>
    <message>
        <source>Symlink to Special</source>
        <translation>Specjalne dowiązanie symboliczne</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Dir</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Specjalny</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otwórz</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Zapi&amp;sz</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Zmień nazwę</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <source>R&amp;eload</source>
        <translation>Odczytaj powtórni&amp;e</translation>
    </message>
    <message>
        <source>Sort by &amp;Name</source>
        <translation>Sortuj według &amp;nazwy</translation>
    </message>
    <message>
        <source>Sort by &amp;Size</source>
        <translation>Sortuj według &amp;rozmiaru</translation>
    </message>
    <message>
        <source>Sort by &amp;Date</source>
        <translation>Sortuj według &amp;daty</translation>
    </message>
    <message>
        <source>&amp;Unsorted</source>
        <translation>&amp;Nieposortowane</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Sortuj</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Pokaż u&amp;kryte pliki</translation>
    </message>
    <message>
        <source>the file</source>
        <translation>plik</translation>
    </message>
    <message>
        <source>the directory</source>
        <translation>katalog</translation>
    </message>
    <message>
        <source>the symlink</source>
        <translation>dowiązanie symboliczne</translation>
    </message>
    <message>
        <source>Delete %1</source>
        <translation>Usuń % 1</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Are you sure you wish to delete %1 &quot;%2&quot;?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Czy jesteś pewien, że chcesz usunąć %1 &quot;%2&quot;?&lt;/qt&gt; </translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>New Folder 1</source>
        <translation>Nowy katalog 1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nowy katalog</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <translation>Nowy katalog %1</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Znajdź katalog</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Katalogi</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Katalog:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>%1
File not found.
Check path and filename.</source>
        <translation>%1
Nie znaleziono pliku.
Sprawdź ściężkę i nazwę pliku.</translation>
    </message>
</context>
<context>
    <name>QFont</name>
    <message>
        <source>Latin</source>
        <translation>Łacina</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Greka</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Cyrylica</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thai</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lao</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Han</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hiragana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hangul</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bopomofo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ethiopic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canadian Aboriginal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mongolian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Currency Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letterlike Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Forms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mathematical Operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Technical Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Geometric Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miscellaneous Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enclosed and Square</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Braille</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Font</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>St&amp;yl fontu</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Rozmiar</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Effekty</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Podkreślenie</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Kolor</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Próbka</translation>
    </message>
    <message>
        <source>Scr&amp;ipt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Porzuć</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Wybierz font</translation>
    </message>
</context>
<context>
    <name>QInputDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Porzuć</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Porzuć</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation>&amp;Porzuć</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Ponów</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignoruj</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPrintDialog</name>
    <message>
        <source>locally connected</source>
        <translation>lokalny</translation>
    </message>
    <message>
        <source>Aliases: %1</source>
        <translation>Alias: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nieznany</translation>
    </message>
    <message>
        <source>Unknown Location</source>
        <translation>Unknown Location</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Porzuć</translation>
    </message>
    <message>
        <source>Printer settings</source>
        <translation>Ustawienia drukarki</translation>
    </message>
    <message>
        <source>Print in color if available</source>
        <translation>Drukuj w kolorze jeśli możliwe</translation>
    </message>
    <message>
        <source>Print in grayscale</source>
        <translation>Drukuj w odcieniach szarości</translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation>Drukarka</translation>
    </message>
    <message>
        <source>Print to printer:</source>
        <translation>Drukarka:</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Drukarka</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentarz</translation>
    </message>
    <message>
        <source>Print to file:</source>
        <translation>Plik:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Przeglądaj...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Drukuj wszystko</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Zakres drukowania</translation>
    </message>
    <message>
        <source>From page:</source>
        <translation>Od strony:</translation>
    </message>
    <message>
        <source>To page:</source>
        <translation>Do strony:</translation>
    </message>
    <message>
        <source>Print first page first</source>
        <translation>Drukuj pierwszą stronę jako pierwszą</translation>
    </message>
    <message>
        <source>Print last page first</source>
        <translation>Drukuj ostatnią stronę jako pierwszą</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Liczba kopii:</translation>
    </message>
    <message>
        <source>Paper format</source>
        <translation>Format paieru</translation>
    </message>
    <message>
        <source>Portrait</source>
        <translation>Pionowo</translation>
    </message>
    <message>
        <source>Landscape</source>
        <translation>Poziomo</translation>
    </message>
    <message>
        <source>A0 (841 x 1189 mm)</source>
        <translation>A0 (841 x 1189 mm)</translation>
    </message>
    <message>
        <source>A1 (594 x 841 mm)</source>
        <translation>A1 (594 x 841 mm)</translation>
    </message>
    <message>
        <source>A2 (420 x 594 mm)</source>
        <translation>A2 (420 x 594 mm)</translation>
    </message>
    <message>
        <source>A3 (297 x 420 mm)</source>
        <translation>A3 (297 x 420 mm)</translation>
    </message>
    <message>
        <source>A4 (210x297 mm, 8.26x11.7 inches)</source>
        <translation>A4 (210 x 297 mm, 8.26 x 11.7 cala)</translation>
    </message>
    <message>
        <source>A5 (148 x 210 mm)</source>
        <translation>A5 (148 x 210 mm)</translation>
    </message>
    <message>
        <source>A6 (105 x 148 mm)</source>
        <translation>A5 (105 x 148 mm)</translation>
    </message>
    <message>
        <source>A7 (74 x 105 mm)</source>
        <translation>A7 (74 x 105 mm)</translation>
    </message>
    <message>
        <source>A8 (52 x 74 mm)</source>
        <translation>A8 (52 x 74 mm)</translation>
    </message>
    <message>
        <source>A9 (37 x 52 mm)</source>
        <translation>A9 (37 x 52 mm)</translation>
    </message>
    <message>
        <source>B0 (1000 x 1414 mm)</source>
        <translation>B0 (1000 x 1414 mm)</translation>
    </message>
    <message>
        <source>B1 (707 x 1000 mm)</source>
        <translation>B1 (707 x 1000 mm)</translation>
    </message>
    <message>
        <source>B2 (500 x 707 mm)</source>
        <translation>B2 (500 x 707 mm)</translation>
    </message>
    <message>
        <source>B3 (353 x 500 mm)</source>
        <translation>B3 (353 x 500 mm)</translation>
    </message>
    <message>
        <source>B4 (250 x 353 mm)</source>
        <translation>B4 (250 x 353 mm)</translation>
    </message>
    <message>
        <source>B5 (176 x 250 mm, 6.93x9.84 inches)</source>
        <translation>B5 (176 x 250 mm, 6.93 x 9.84 cala)</translation>
    </message>
    <message>
        <source>B6 (125 x 176 mm)</source>
        <translation>B6 (125 x 176 mm)</translation>
    </message>
    <message>
        <source>B7 (88 x 125 mm)</source>
        <translation>B7 (88 x 125 mm)</translation>
    </message>
    <message>
        <source>B8 (62 x 88 mm)</source>
        <translation>B8 (62 x 88 mm)</translation>
    </message>
    <message>
        <source>B9 (44 x 62 mm)</source>
        <translation>B9 (44 x 62 mm)</translation>
    </message>
    <message>
        <source>B10 (31 x 44 mm)</source>
        <translation>B10 (31 x 44 mm)</translation>
    </message>
    <message>
        <source>C5E (163 x 229 mm)</source>
        <translation>C5E (163 x 229 mm)</translation>
    </message>
    <message>
        <source>DLE (110 x 220 mm)</source>
        <translation>DLE (110 x 220 mm)</translation>
    </message>
    <message>
        <source>Executive (7.5x10 inches, 191x254 mm)</source>
        <translation>Executive (7.5 x 10 cala, 191 x 254 mm)</translation>
    </message>
    <message>
        <source>Folio (210 x 330 mm)</source>
        <translation>Folio (210 x 330 mm)</translation>
    </message>
    <message>
        <source>Ledger (432 x 279 mm)</source>
        <translation>Ledger (432 x 279 mm)</translation>
    </message>
    <message>
        <source>Legal (8.5x14 inches, 216x356 mm)</source>
        <translation>Legal (8.5 x14 cala, 216 x 356 mm)</translation>
    </message>
    <message>
        <source>Letter (8.5x11 inches, 216x279 mm)</source>
        <translation>Letter (8.5 x 11 cala, 216 x 279 mm)</translation>
    </message>
    <message>
        <source>Tabloid (279 x 432 mm)</source>
        <translation>Tabloid (279 x 432 mm)</translation>
    </message>
    <message>
        <source>US Common #10 Envelope (105 x 241 mm)</source>
        <translation>US Common #10 Envelope (105 x 241 mm)</translation>
    </message>
    <message>
        <source>Setup Printer</source>
        <translation>Ustawienia drukarki</translation>
    </message>
    <message>
        <source>PostScript Files (*.ps);;All Files (*)</source>
        <translation>Pliki postscriptowe  (*.ps);;Wszystkie pliki (*)</translation>
    </message>
</context>
<context>
    <name>QWhatsThisButton</name>
    <message>
        <source>What&apos;s this?</source>
        <translation>Co to jest?</translation>
    </message>
</context>
</TS>
